==> verttice_ui-0.0.97.tar.gz: lib/src/widgets/data_factory/table_factory/table_utils.dart <==
import 'package:verttice_logic/verttice_logic.dart';

bool applayTableFilter({
  required FilterField filter,
  required dynamic cellData,
}) {
  if (filter.value == null) {
    return true;
  } else if (cellData == null) {
    return false;
  } else if (filter.filterType == FilterTypesFF.string ||
      filter.filterType == FilterTypesFF.stringList) {
    if (filter.value is String) {
      if (cellData
          .toString()
          .toLowerCase()
          .contains(filter.value.toLowerCase())) {
        return true;
      }
    } else if (filter.value is List && filter.value.isNotEmpty) {
      for (var valueList in (filter.value as List)) {
        if (valueList != null && valueList != '') {
          if (cellData
              .toString()
              .toLowerCase()
              .contains(valueList.toLowerCase())) {
            return true;
          }
        }
      }
    }
  } else if (filter.filterType == FilterTypesFF.number) {
    if (filter.value is Map &&
        filter.value['smallNumber'] != null &&
        filter.value['smallNumber'] is int &&
        filter.value['bigNumber'] != null &&
        filter.value['bigNumber'] is int &&
        (cellData is int) &&
        (cellData > filter.value["smallNumber"]) &&
        (cellData < filter.value["bigNumber"])) {
      return true;
    } else if (filter.value is Map &&
        filter.value['smallNumber'] != null &&
        filter.value['smallNumber'] is int &&
        (cellData is int) &&
        (cellData > filter.value["smallNumber"])) {
      return true;
    } else if (filter.value is Map &&
        filter.value['bigNumber'] != null &&
        filter.value['bigNumber'] is int &&
        (cellData is int) &&
        (cellData < filter.value["bigNumber"])) {
      return true;
    }
  } else if (filter.filterType == FilterTypesFF.numberRange) {
  } else if (filter.filterType == FilterTypesFF.date) {
    if (filter.value is Map &&
        filter.value['startDate'] != null &&
        filter.value['startDate'] is int &&
        filter.value['endDate'] != null &&
        filter.value['endDate'] is int &&
        (cellData is int) &&
        (cellData > filter.value["startDate"]) &&
        (cellData < filter.value["endDate"])) {
      return true;
    } else if (filter.value is Map &&
        filter.value['startDate'] != null &&
        filter.value['startDate'] is int &&
        (cellData is int) &&
        (cellData > filter.value["startDate"])) {
      return true;
    } else if (filter.value is Map &&
        filter.value['endDate'] != null &&
        filter.value['endDate'] is int &&
        (cellData is int) &&
        (cellData < filter.value["endDate"])) {
      return true;
    }
  } else if (filter.filterType == FilterTypesFF.dateRange) {
    if (filter.value is Map &&
        filter.value['startDate'] != null &&
        filter.value['startDate'] is int &&
        filter.value['endDate'] != null &&
        filter.value['endDate'] is int &&
        (cellData is Map) &&
        (cellData['startDate'] is int) &&
        (cellData['endDate'] is int) &&
        (cellData['startDate'] > filter.value["startDate"]) &&
        (cellData['endDate'] < filter.value["endDate"])) {
      return true;
    } else if (filter.value is Map &&
        filter.value['startDate'] != null &&
        filter.value['startDate'] is int &&
        (cellData is Map) &&
        (cellData['startDate'] is int) &&
        (cellData['startDate'] > filter.value["startDate"])) {
      return true;
    } else if (filter.value is Map &&
        filter.value['endDate'] != null &&
        filter.value['endDate'] is int &&
        (cellData is Map) &&
        (cellData['endDate'] is int) &&
        (cellData['endDate'] < filter.value["endDate"])) {
      return true;
    }
  } else if (filter.filterType == FilterTypesFF.time) {
    if (filter.value is Map &&
        filter.value['startTime'] != null &&
        filter.value['startTime'] is int &&
        filter.value['endTime'] != null &&
        filter.value['endTime'] is int &&
        (cellData is int) &&
        (cellData > filter.value["startTime"]) &&
        (cellData < filter.value["endTime"])) {
      return true;
    } else if (filter.value is Map &&
        filter.value['startTime'] != null &&
        filter.value['startTime'] is int &&
        (cellData is int) &&
        (cellData > filter.value["startTime"])) {
      return true;
    } else if (filter.value is Map &&
        filter.value['endTime'] != null &&
        filter.value['endTime'] is int &&
        (cellData is int) &&
        (cellData < filter.value["endTime"])) {
      return true;
    }
  } else if (filter.filterType == FilterTypesFF.timeRange) {
  } else if (filter.filterType == FilterTypesFF.bool) {
  } else if (filter.filterType == FilterTypesFF.geo) {}

  return false;
}

==> verttice_ui-0.0.150.tar.gz: lib/src/widgets/data_factory/table_factory/table_utils.dart <==
// 📦 Package imports:
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_models/verttice_models.dart';

bool applyTableFilter({
  required FilterField filter,
  required dynamic cellData,
}) {
  if (filter.value == null) {
    return true;
  } else if (cellData == null) {
    return false;
  } else if (filter.filterType == FilterTypesFF.string ||
      filter.filterType == FilterTypesFF.stringList) {
    if (filter.value is String) {
      if (DataClassUtils.dynamicToString(cellData)
          .toLowerCase()
          .contains(filter.value.toLowerCase())) {
        return true;
      }
    } else if (filter.value is List && filter.value.isNotEmpty) {
      for (var valueList in (filter.value as List)) {
        if (valueList != null && valueList != '') {
          if (DataClassUtils.dynamicToString(cellData)
              .toLowerCase()
              .contains(valueList.toLowerCase())) {
            return true;
          }
        }
      }
    }
  } else if (filter.filterType == FilterTypesFF.number) {
    if (filter.value is Map &&
        filter.value['lowNumber'] != null &&
        filter.value['lowNumber'] is num &&
        filter.value['heighNumber'] != null &&
        filter.value['heighNumber'] is num &&
        (cellData is num) &&
        (cellData >= filter.value["lowNumber"]) &&
        (cellData <= filter.value["heighNumber"])) {
      return true;
    } else if (filter.value is Map &&
        filter.value['lowNumber'] != null &&
        filter.value['lowNumber'] is num &&
        (cellData is num) &&
        (cellData >= filter.value["lowNumber"])) {
      return true;
    } else if (filter.value is Map &&
        filter.value['heighNumber'] != null &&
        filter.value['heighNumber'] is num &&
        (cellData is num) &&
        (cellData <= filter.value["heighNumber"])) {
      return true;
    }
  } else if (filter.filterType == FilterTypesFF.numberRange) {
  } else if (filter.filterType == FilterTypesFF.date) {
    if (filter.value is Map &&
        filter.value['startDate'] != null &&
        filter.value['startDate'] is int &&
        filter.value['endDate'] != null &&
        filter.value['endDate'] is int &&
        (cellData is int) &&
        (cellData >= filter.value["startDate"]) &&
        (cellData <= filter.value["endDate"])) {
      return true;
    } else if (filter.value is Map &&
        filter.value['startDate'] != null &&
        filter.value['startDate'] is int &&
        (cellData is int) &&
        (cellData >= filter.value["startDate"])) {
      return true;
    } else if (filter.value is Map &&
        filter.value['endDate'] != null &&
        filter.value['endDate'] is int &&
        (cellData is int) &&
        (cellData <= filter.value["endDate"])) {
      return true;
    }
  } else if (filter.filterType == FilterTypesFF.dateRange) {
    if (filter.value is Map &&
        filter.value['startDate'] != null &&
        filter.value['startDate'] is int &&
        filter.value['endDate'] != null &&
        filter.value['endDate'] is int &&
        (cellData is Map) &&
        (cellData['startDate'] is int) &&
        (cellData['endDate'] is int) &&
        (cellData['startDate'] >= filter.value["startDate"]) &&
        (cellData['endDate'] <= filter.value["endDate"])) {
      return true;
    } else if (filter.value is Map &&
        filter.value['startDate'] != null &&
        filter.value['startDate'] is int &&
        (cellData is Map) &&
        (cellData['startDate'] is int) &&
        (cellData['startDate'] >= filter.value["startDate"])) {
      return true;
    } else if (filter.value is Map &&
        filter.value['endDate'] != null &&
        filter.value['endDate'] is int &&
        (cellData is Map) &&
        (cellData['endDate'] is int) &&
        (cellData['endDate'] <= filter.value["endDate"])) {
      return true;
    }
  } else if (filter.filterType == FilterTypesFF.time) {
    if (filter.value is Map &&
        filter.value['startTime'] != null &&
        filter.value['startTime'] is int &&
        filter.value['endTime'] != null &&
        filter.value['endTime'] is int &&
        (cellData is int) &&
        (cellData >= filter.value["startTime"]) &&
        (cellData <= filter.value["endTime"])) {
      return true;
    } else if (filter.value is Map &&
        filter.value['startTime'] != null &&
        filter.value['startTime'] is int &&
        (cellData is int) &&
        (cellData >= filter.value["startTime"])) {
      return true;
    } else if (filter.value is Map &&
        filter.value['endTime'] != null &&
        filter.value['endTime'] is int &&
        (cellData is int) &&
        (cellData <= filter.value["endTime"])) {
      return true;
    }
  } else if (filter.filterType == FilterTypesFF.timeRange) {
  } else if (filter.filterType == FilterTypesFF.bool) {
  } else if (filter.filterType == FilterTypesFF.geo) {}

  return false;
}
